// AeS加解密接口
// 秒寻科技
// 2024-02-18
// 周涛

package util

import (
	"bytes"
	"crypto/aes"
	"crypto/cipher"
	"encoding/base64"
	"errors"
)

// 加密：先Aes加密，之后在base64加密
// 三种密码标准：128 位、192 位和 256 位，分别对应key字符串位数 16、32、64
func EncryptAes(data []byte) (string, error) {
	//获得密钥
	myViper := GetViper()
	aeskey := myViper.GetString("aeskey.key128")

	//aes加密
	res, err := aesEncrypt(data, []byte(aeskey))
	if err != nil {
		return "", err
	}

	return base64.StdEncoding.EncodeToString(res), nil
}

// 解密，先base64解密，之后再aes解密
func DecryptAes(data string) (string, error) {
	//获得密钥
	myViper := GetViper()
	aeskey := myViper.GetString("aeskey.key128")

	//base64解码
	ciphertext, err := base64.StdEncoding.DecodeString(data)
	if err != nil {
		return "", err
	}

	//aes解密
	dataList, err := aesDecrypt(ciphertext, []byte(aeskey))
	if err != nil {
		return "", err
	}

	plaintext := string(dataList)

	return plaintext, nil
}

// 加密
func aesEncrypt(data []byte, key []byte) ([]byte, error) {
	// 创建加密实例
	block, err := aes.NewCipher(key)
	if err != nil {
		return nil, err
	}
	// 判断加密快的大小
	blockSize := block.BlockSize()

	// 填充
	encryptBytes := pkcs7Padding(data, blockSize)

	// 初始化加密数据接收切片
	crypted := make([]byte, len(encryptBytes))

	// 使用cbc加密模式
	blockMode := cipher.NewCBCEncrypter(block, key) // Cipher Block Chaining：加密块链

	// 执行加密
	blockMode.CryptBlocks(crypted, encryptBytes)
	return crypted, nil
}

// 解密
func aesDecrypt(data []byte, key []byte) ([]byte, error) {
	// 创建实例
	block, err := aes.NewCipher(key)
	if err != nil {
		return nil, err
	}

	// 获取块的大小
	//blockSize := block.BlockSize()

	// 使用cbc
	blockMode := cipher.NewCBCDecrypter(block, key) // Cipher Block Chaining：加密块链

	// 初始化解密数据接收切片
	crypted := make([]byte, len(data))

	// 执行解密
	blockMode.CryptBlocks(crypted, data)

	// 去除填充
	crypted, err = pkcs7UnPadding(crypted)
	if err != nil {
		return nil, err
	}
	return crypted, nil
}

// pkcs7Padding 填充
func pkcs7Padding(data []byte, blockSize int) []byte {
	// 判断缺少几位长度。最少1，最多 blockSize
	padding := blockSize - len(data)%blockSize
	// 补足位数。把切片[]byte{byte(padding)}复制padding个
	padText := bytes.Repeat([]byte{byte(padding)}, padding)
	return append(data, padText...)
}

// pkcs7UnPadding 填充的反向操作
func pkcs7UnPadding(data []byte) ([]byte, error) {
	length := len(data)
	if length == 0 {
		return nil, errors.New("加密字符串错误！")
	}
	// 获取填充的个数
	unPadding := int(data[length-1])
	return data[:(length - unPadding)], nil
}
